import { useCollocation } from "@/modules/collocation";
import { initQueditor } from "@queenjs-modules/queditor";
import { initExpViewer } from "@queenjs-modules/queentree-explorer-viewer";
import { defineComponent, onMounted } from "vue";
import { useRoute } from "vue-router";
import Header from "./components/Header";
import RightPanel from "./components/RightPanel";

export default defineComponent({
  setup() {
    const { params } = useRoute();
    const collocatin = useCollocation();

    onMounted(() => collocatin.actions.queryStyleDetail(params.id as string));

    const expViewer = initExpViewer({
      modules: {
        queditor: initQueditor({
          config: {
            dragEnable: true,
          },
        }),
      },
    });

    const { queditor } = expViewer.modules;

    expViewer.initComponents({
      Viewport: {
        Header: {
          default: Header,
        },
        EditPanel: {
          default: RightPanel,
        },
      },
    });

    queditor.initComponents({
      Viewport: {
        Toolbar: {
          default: () => null,
        },
      },
    });

    return () => (
      <div class="h-100vh">
        <expViewer.components.Viewport />
      </div>
    );
  },
});
